@@ -24,15 +24,15 @@
 #define STRINGSEXTRACTTOOL_H
 
 // lib
-#include "oktetakastencontrollers_export.h"
+#include <kasten/okteta/oktetakastencontrollers_export.h>
 // tool
 #include "containedstring.h"
 // Kasten core
-#include <abstracttool.h>
+#include <kasten/abstracttool.h>
 // Okteta core
-#include <addressrange.h>
+#include <okteta/addressrange.h>
 // Qt
-#include <QtCore/QList>
+#include <QList>
 
 namespace Okteta {
 class AbstractByteArrayModel;
